pub enum PacketStreamStartError {
DeviceError,
AlreadyPending,
AlreadyStarted,
// some variants omitted
}Expand description
Errors returned by PacketStream/Start.
Variants
DeviceError
This device has encountered an error and can no longer be controlled.
AlreadyPending
The previous Start call has not yet completed.
AlreadyStarted
Start was called on a packet stream that is already started.
Implementations
Sourceimpl PacketStreamStartError
impl PacketStreamStartError
pub fn from_primitive(prim: u32) -> Option<Self>
pub fn from_primitive_allow_unknown(prim: u32) -> Self
pub fn unknown() -> Self
pub const fn into_primitive(self) -> u32
pub fn is_unknown(&self) -> bool