pub enum PacketStreamSupportedFormats {
PcmFormat(PcmFormatSet),
SupportedEncodings(SupportedEncodings),
// some variants omitted
}Expand description
This union represents a specific set of formats supported by a packet stream. A packet stream may support uncompressed PCM, encoded audio, or both. A vector of this union is used to describe the possible formats that a packet stream can support.
Variants
PcmFormat(PcmFormatSet)
Supported formats for uncompressed PCM audio.
SupportedEncodings(SupportedEncodings)
Supported formats for encoded audio (e.g. AAC, SBC).
Implementations
Sourceimpl PacketStreamSupportedFormats
impl PacketStreamSupportedFormats
pub fn ordinal(&self) -> u64
pub fn unknown_variant_for_testing() -> Self
pub fn is_unknown(&self) -> bool