pub struct ElementPacketStreamFormatSet {
pub element_id: Option<u64>,
pub format_sets: Option<Vec<PacketStreamSupportedFormats>>,
/* private fields */
}Expand description
This table represents the possible Packet Stream formats that this element can support.
Fields
element_id: Option<u64>The ID of the element being described. This must match a PACKET_STREAM
entry in the list of elements contained in the device’s Info table.
Required.
format_sets: Option<Vec<PacketStreamSupportedFormats>>The format sets that this element supports.
Required. Must contain at least one entry.